@@ -17,13 +17,10 @@ return {
         capture_if    => 'eth0',
         capture_ports => [ 80, ],
         redirect_port => 80,
-        capture_net   => '10.10/16',
+        capture_net   => '10.10.0.0/16',
         throttle      => OFF,
 
-        dhcp_servers  => [],
-        dns_servers   => [],
-        ldap_servers  => [],
-        mail_servers  => [],
+        open_services => {},
         open_clients  => [],
         open_servers  => [],
         open_networks => [],
